Groggy Streaming Visualizer Template

# 🎨 Groggy Streaming Visualizer Prototype

View:
Node Size: 8
Edge Curviness: 0.2

### Live Style Editor

🎛️ Controls
💻 CSS

#### Node Styling

Default Color:
Selected Color:
Hover Color:

#### Edge Styling

Default Color:
Width:

#### Table Styling

Border Color:
Hover Color:

#### Quick Presets:

🌙 Dark
⚪ Minimal
🌈 Colorful
⚡ Neon
🎨 Interactive Visualization
Sample data × 6 cols
Prototype Mode

ID | Name | Type | Value | Connected | Weight
--- | --- | --- | --- | --- | ---

Layout: